OC.L10N.register(
    "gallery",
    {
    "Delete" : "Skrap",
    "Share" : "Deel",
    "Error" : "Fout",
    "Share link" : "Deelskakel",
    "Link" : "Skakel",
    "Password" : "Wagwoord",
    "Send" : "Stuur",
    "group" : "Groep",
    "access control" : "toegangbeheer",
    "create" : "skep",
    "change" : "verander",
    "delete" : "skrap",
    "shared by %s" : "gedeel deur %s",
    "Direct link" : "Direkte skakel",
    "File list" : "Lêerlys"
},
"nplurals=2; plural=(n != 1);");
